## 1.0.3 (2025-02-04)

### Fix

- **build**: fixed build of project did not including all source files

## 1.0.2 (2025-02-03)

### Fix

- **_logger.py**: fixed some typing issues

## 1.0.1 (2024-11-28)

### Fix

- **README.md**: updated descriptions and some phrasing for clarity
- **__main__.py**: updated the example to write to a temporary file

## 0.2.0 (2024-11-22)

### Feat

- initialized project for installation using uv and a minimal setup with nix for dev
